from predicthq.endpoints.base import UserBaseEndpoint
from predicthq.endpoints.decorators import accepts, returns
from .schemas import (
    FeatureRequest, FeatureResultSet
)


class FeaturesEndpoint(UserBaseEndpoint):

    @accepts(FeatureRequest, query_string=False)
    @returns(FeatureResultSet)
    def obtain_features(self, **request):
        return self.client.post(self.build_url('v1', 'features'), json=request)



from .oauth2 import OAuth2Endpoint
from .v1.accounts import AccountsEndpoint
from .v1.broadcasts import BroadcastsEndpoint
from .v1.events import EventsEndpoint
from .v1.features import FeaturesEndpoint
from .v1.places import PlacesEndpoint


__all__ = [
    'OAuth2Endpoint',
    'AccountsEndpoint',
    'BroadcastsEndpoint',
    'EventsEndpoint',
    'FeaturesEndpoint',
    'PlacesEndpoint',
]
